@@ -56,8 +56,8 @@ private Q_SLOTS:
 private:
     void insertRecord(int row, Record* record);
     static void appendRecord(QQmlListProperty<Record>* list, Record* record);
-    static int countRecords(QQmlListProperty<Record>* list);
-    static Record* recordAt(QQmlListProperty<Record>* list, int index);
+    static qsizetype countRecords(QQmlListProperty<Record>* list);
+    static Record* recordAt(QQmlListProperty<Record>* list, qsizetype index);
     static void clearRecords(QQmlListProperty<Record>* list);
     QList<Record*> m_records;
     int m_columns;
